==> svm-22.0.0-sources.jar: com/oracle/svm/core/genscavenge/RuntimeCodeInfoGCSupportImpl.java <==
/*
 * Copyright (c) 2020, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.genscavenge;

import org.graalvm.nativeimage.Platform;
import org.graalvm.nativeimage.Platforms;

import com.oracle.svm.core.annotate.Uninterruptible;
import com.oracle.svm.core.code.CodeInfo;
import com.oracle.svm.core.heap.RuntimeCodeInfoGCSupport;

public class RuntimeCodeInfoGCSupportImpl extends RuntimeCodeInfoGCSupport {
    @Platforms(Platform.HOSTED_ONLY.class)
    RuntimeCodeInfoGCSupportImpl() {
    }

    @Override
    @Uninterruptible(reason = "Called when installing code.", callerMustBe = true)
    public void registerObjectFields(CodeInfo codeInfo) {
        // nothing to do (all runtime compiled code gets processed at every GC)
    }

    @Override
    @Uninterruptible(reason = "Called when installing code.", callerMustBe = true)
    public void registerCodeConstants(CodeInfo codeInfo) {
        // nothing to do (see above)
    }

    @Override
    @Uninterruptible(reason = "Called when installing code.", callerMustBe = true)
    public void registerFrameMetadata(CodeInfo codeInfo) {
        // nothing to do (see above)
    }

    @Override
    @Uninterruptible(reason = "Called when installing code.", callerMustBe = true)
    public void registerDeoptMetadata(CodeInfo codeInfo) {
        // nothing to do (see above)
    }

    @Override
    @Uninterruptible(reason = "Called when freeing code.", callerMustBe = true)
    public void unregisterCodeConstants(CodeInfo codeInfo) {
        // nothing to do (see above)
    }

    @Override
    @Uninterruptible(reason = "Called when freeing code.", callerMustBe = true)
    public void unregisterRuntimeCodeInfo(CodeInfo codeInfo) {
        // nothing to do (see above)
    }
}

==> svm-23.0.1-sources.jar: com/oracle/svm/core/genscavenge/RuntimeCodeInfoGCSupportImpl.java <==
/*
 * Copyright (c) 2020, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.genscavenge;

import org.graalvm.nativeimage.Platform;
import org.graalvm.nativeimage.Platforms;

import com.oracle.svm.core.Uninterruptible;
import com.oracle.svm.core.code.CodeInfo;
import com.oracle.svm.core.heap.RuntimeCodeInfoGCSupport;

public class RuntimeCodeInfoGCSupportImpl extends RuntimeCodeInfoGCSupport {
    @Platforms(Platform.HOSTED_ONLY.class)
    RuntimeCodeInfoGCSupportImpl() {
    }

    @Override
    @Uninterruptible(reason = "Called when installing code.", callerMustBe = true)
    public void registerObjectFields(CodeInfo codeInfo) {
        // nothing to do (all runtime compiled code gets processed at every GC)
    }

    @Override
    @Uninterruptible(reason = "Called when installing code.", callerMustBe = true)
    public void registerCodeConstants(CodeInfo codeInfo) {
        // nothing to do (see above)
    }

    @Override
    @Uninterruptible(reason = "Called when installing code.", callerMustBe = true)
    public void registerFrameMetadata(CodeInfo codeInfo) {
        // nothing to do (see above)
    }

    @Override
    @Uninterruptible(reason = "Called when installing code.", callerMustBe = true)
    public void registerDeoptMetadata(CodeInfo codeInfo) {
        // nothing to do (see above)
    }

    @Override
    @Uninterruptible(reason = "Called when freeing code.", callerMustBe = true)
    public void unregisterCodeConstants(CodeInfo codeInfo) {
        // nothing to do (see above)
    }

    @Override
    @Uninterruptible(reason = "Called when freeing code.", callerMustBe = true)
    public void unregisterRuntimeCodeInfo(CodeInfo codeInfo) {
        // nothing to do (see above)
    }
}
